@@ -8,6 +8,8 @@ def build_parser(stud_file: dict) -> argparse.ArgumentParser:
     # options = parser.parse_args(args)
 
     for key in stud_file:
+        if key.startswith('.'):
+            continue
         help = ''
         if 'help' in stud_file[key]:
             help = stud_file[key]['help']
